@@ -379,6 +379,7 @@ class iniParser(cl_profile._error):
                 return False
             self.checkIni = "samba"
             # В файле есть данные
+            textIni = re.sub(r"^#.*$",textIni,'',re.M)
             if not self.isEmptyFile(textIni):
                 try:
                     objIni = cl_profile.plasma(textIni)
@@ -878,6 +879,8 @@ class DataVars(object):
         calculate_ini = self.__getPathCalculateIni()
         # получаем полный путь до файла ini
         if location == 'default':
+            name_calculate_ini = calculate_ini[3]
+        if location == 'custom':
             name_calculate_ini = calculate_ini[2]
         elif location == 'local':
             name_calculate_ini = calculate_ini[1]
@@ -917,6 +920,8 @@ class DataVars(object):
         calculate_ini = self.__getPathCalculateIni()
         # получаем полный путь до файла ini
         if location == 'default':
+            name_calculate_ini = calculate_ini[3]
+        if location == 'custom':
             name_calculate_ini = calculate_ini[2]
         elif location == 'local':
             name_calculate_ini = calculate_ini[1]
@@ -1000,7 +1005,7 @@ class DataVars(object):
         act_section = self.__getActiveSections()
         set_act_section = set(act_section)
         i = 0
-        locations = ['remote','local','default']
+        locations = ['remote','local','custom','default']
         for name_calculate_ini in calculate_ini:
             # проверить сущестование ini файла
             if os.path.exists(name_calculate_ini):
